#!/usr/bin/python

# --
#                 - Mellanox Confidential and Proprietary -
#
# Copyright (C) Jan 2013, Mellanox Technologies Ltd.  ALL RIGHTS RESERVED.
#
# Except as specifically permitted herein, no portion of the information,
# including but not limited to object code and source code, may be reproduced,
# modified, distributed, republished or otherwise exploited in any form or by
# any means for any purpose without the prior written permission of Mellanox
# Technologies Ltd. Use of software subject to the terms and conditions
# detailed in the file "LICENSE.txt".
# --

"""
    Metaclass definitions
"""


class MSingletonMeta(type):
    """Singleton metaclass"""
    def __call__(cls, *args, **kwargs):
        try:
            return cls.__instance
        except AttributeError:
            cls.__instance = super(MSingletonMeta, cls).__call__(
                *args, **kwargs)
            return cls.__instance


class MEnumMeta(type):
    """Enumerated type metaclass"""
    def __call__(cls, *args, **kwargs):
        raise RuntimeError("cannot instantiate enumerated type")

    def __delattr__(self, item):
        raise RuntimeError("cannot modify enumerated type")

    def __setattr__(self, key, value):
        raise RuntimeError("cannot modify enumerated type")
