# --
#                 - Mellanox Confidential and Proprietary -
#
# Copyright (C) Jan 2013, Mellanox Technologies Ltd.  ALL RIGHTS RESERVED.
#
# Except as specifically permitted herein, no portion of the information,
# including but not limited to object code and source code, may be reproduced,
# modified, distributed, republished or otherwise exploited in any form or by
# any means for any purpose without the prior written permission of Mellanox
# Technologies Ltd. Use of software subject to the terms and conditions
# detailed in the file "LICENSE.txt".
# --


# @author: Simon Raviv
# @date: May 24, 2017

import time

from connectx_device_mcra import ConnectXDeviceMCRA
from connectx5_mcra import ConnectX5MCRACountres
from bluefield_mcra import BlueFieldMCRACountres
from performance.common.device_family import DeviceFamily
from performance.performance_exceptions import PerformanceException
from performance.services.analysis.analyzers.layer_3.cx_family_pci_latency \
    import CXFamilyPCILatencyAvg, CXFamilyPCILatencyMin, CXFamilyPCILatencyMax
from performance.services.analysis.analyzers.layer_3. \
    cx_family_pci_pxt_to_pxdp_latency import \
    CXFamilyPCIPXTToPXDPLatencyAvg, \
    CXFamilyPCIPXTToPXDPLatencyMin, \
    CXFamilyPCIPXTToPXDPLatencyMax
from performance.services.analysis.analyzers.layer_4. \
    cx5_family_packet_rate import \
    CX5FamilyRXPacketRate, \
    CX5FamilyTXPacketRate
from performance.services.analysis.analyzers.layer_4. \
    cx5_family_bw import \
    CX5FamilyRXBandWidth, \
    CX5FamilyTXBandWidth
from performance.services.analysis.analyzers.layer_4. \
    cx5_family_pci_outbound import \
    CX5FamilyPCIOutboundUsedBW, \
    CX5FamilyPCIOutboundAvailableBW, \
    CX5FamilyPCIOutboundUtilizationBW
from performance.services.analysis.analyzers.layer_4. \
    cx5_family_pci_inbound import \
    CX5FamilyPCIInboundUtilizationBW
from performance.services.analysis.analyzers.layer_4. \
    cx5_family_optimal_hops_per_packet import \
    CX5FamilyRXOptimalHopsPerPacket, \
    CX5FamilyTXOptimalHopsPerPacket
from performance.services.analysis.analyzers.layer_3. \
    cx_family_optimal_packet_rate_bottleneck import \
    CXFamilyRXOptimalPacketRateBN, \
    CXFamilyTXOptimalPacketRateBN
from performance.services.analysis.analyzers.layer_4. \
    cx5_family_hops_per_packet import \
    CX5FamilyRXHopsPerPacket, \
    CX5FamilyTXHopsPerPacket
from performance.services.analysis.analyzers.layer_4. \
    cx5_family_packet_rate_bottleneck import \
    CX5FamilyRXPacketRateBN, \
    CX5FamilyTXPacketRateBN
from performance.services.analysis.analyzers.layer_3. \
    cx_family_rx_indirect_mem_key_rate import \
    CXFamilyRXInderectMemKeyRate


class ConnectX5DeviceMCRA(ConnectXDeviceMCRA):
    """ Represents ConnectX5/5EX counters definitions.
    """
    def __init__(self, mstdev, device_id):
        super(ConnectX5DeviceMCRA, self).__init__(mstdev,
                                                  DeviceFamily.CONNECTX5,
                                                  device_id)

        if self.device_id > 0:
            if ConnectX5MCRACountres.is_device_id_ok(self.device_id):
                self.mcra = ConnectX5MCRACountres(device=self.mf)
            elif BlueFieldMCRACountres.is_device_id_ok(self.device_id):
                self.mcra = BlueFieldMCRACountres(device=self.mf)

        if self.mcra is None:
            error_message = self.device_error_message.format(
                device_id=self.device_id)
            self.set_error(error_message)

        self._initialize_analyzers()

    def _initialize_analyzers(self):
        """ Initialize ConnectX-5/5 EX specific analyzer.
        """
        super(ConnectX5DeviceMCRA, self)._initialize_analyzers()
        self._analyzers += [
            CXFamilyPCILatencyAvg(),
            CXFamilyPCILatencyMin(),
            CXFamilyPCILatencyMax(),
            CXFamilyPCIPXTToPXDPLatencyAvg(),
            CXFamilyPCIPXTToPXDPLatencyMin(),
            CXFamilyPCIPXTToPXDPLatencyMax(),
            CX5FamilyRXPacketRate(),
            CX5FamilyTXPacketRate(),
            CX5FamilyRXBandWidth(),
            CX5FamilyTXBandWidth(),
            CX5FamilyPCIOutboundUsedBW(),
            CX5FamilyPCIOutboundAvailableBW(),
            CX5FamilyPCIOutboundUtilizationBW(),
            CX5FamilyPCIInboundUtilizationBW(),
            CX5FamilyRXOptimalHopsPerPacket(),
            CXFamilyRXOptimalPacketRateBN(),
            CX5FamilyRXHopsPerPacket(),
            CX5FamilyRXPacketRateBN(),
            CX5FamilyTXHopsPerPacket(),
            CX5FamilyTXPacketRateBN(),
            CX5FamilyTXOptimalHopsPerPacket(),
            CXFamilyTXOptimalPacketRateBN(),
            CXFamilyRXInderectMemKeyRate()
            ]
